@@ -6,7 +6,7 @@ use Stenciller::Wrap;
 
 package Stenciller;
 
-our $VERSION = '0.1209'; # VERSION:
+our $VERSION = '0.1210'; # VERSION:
 # PODCLASSNAME:
 # ABSTRACT: Transforms a flat file format to different output
 
@@ -32,7 +32,7 @@ Stenciller - Transforms a flat file format to different output
 
 =head1 VERSION
 
-Version 0.1209, released 2015-02-09.
+Version 0.1210, released 2015-02-09.
 
 
 
@@ -153,7 +153,7 @@ there is a header before the first stencil.
 =begin HTML
 
 <table cellpadding="0" cellspacing="0">
-<tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Standard#Stencil">Stencil</a> ]</td>
+<tr><td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#ArrayRef">ArrayRef</a> [ <a href="https://metacpan.org/pod/Types::Stenciller#Stencil">Stencil</a> ]</td>
 <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">not in constructor</td>
 <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td></tr>
 </table>
